@@ -361,6 +361,17 @@ impl VisitMut for Prefixer {
                 same_content!("-ms-flex-order");
             }
 
+            "image-rendering" => {
+                if let ComponentValue::Ident(Ident { value, .. }) = &n.value[0] {
+                    if &**value == "pixelated" {
+                        simple!("-ms-interpolation-mode", "nearest-neighbor");
+                        same_name!("-webkit-optimize-contrast");
+                        same_name!("-moz-crisp-edges");
+                        same_name!("-o-pixelated");
+                    }
+                }
+            }
+
             "flex-direction" => {
                 same_content!("-webkit-flex-direction");
                 same_content!("-ms-flex-direction");
@@ -370,6 +381,10 @@ impl VisitMut for Prefixer {
                 same_content!("-webkit-filter");
             }
 
+            "backdrop-filter" => {
+                same_content!("-webkit-backdrop-filter");
+            }
+
             "mask" => {
                 same_content!("-webkit-mask");
             }
@@ -435,7 +450,18 @@ impl VisitMut for Prefixer {
             "user-select" => {
                 same_content!("-webkit-user-select");
                 same_content!("-moz-user-select");
-                same_content!("-ms-user-select");
+
+                if let ComponentValue::Ident(Ident { value, .. }) = &n.value[0] {
+                    match &**value {
+                        "contain" => {
+                            simple!("-ms-user-select", "element");
+                        }
+                        "all" => {}
+                        _ => {
+                            same_content!("-ms-user-select");
+                        }
+                    }
+                }
             }
 
             "transform" => {
