@@ -8,7 +8,10 @@
 use std::path::PathBuf;
 
 use swc_common::{FileName, DUMMY_SP};
-use swc_css_ast::{ComponentValue, DeclarationOrAtRule, QualifiedRule, SimpleBlock, Stylesheet};
+use swc_css_ast::{
+    ComponentValue, DeclarationOrAtRule, QualifiedRule, QualifiedRulePrelude, SelectorList,
+    SimpleBlock, Stylesheet,
+};
 use swc_css_codegen::{
     writer::basic::{BasicCssWriter, BasicCssWriterConfig},
     CodegenConfig, Emit,
@@ -482,6 +485,15 @@ fn error_recovery_1() {
     );
 }
 
+#[test]
+fn image_rendering() {
+    t(
+        "image-rendering: pixelated;",
+        "-ms-interpolation-mode:nearest-neighbor;image-rendering:-webkit-optimize-contrast;\
+         image-rendering:-moz-crisp-edges;image-rendering:-o-pixelated;image-rendering:pixelated;",
+    );
+}
+
 /// Test
 fn t(src: &str, expected: &str) {
     testing::run_test2(false, |cm, handler| {
@@ -503,10 +515,10 @@ fn t(src: &str, expected: &str) {
 
         let mut node = QualifiedRule {
             span: DUMMY_SP,
-            prelude: swc_css_ast::SelectorList {
+            prelude: QualifiedRulePrelude::SelectorList(SelectorList {
                 span: DUMMY_SP,
                 children: Default::default(),
-            },
+            }),
             block: SimpleBlock {
                 span: DUMMY_SP,
                 name: '{',
@@ -580,7 +592,7 @@ fn fixture(input: PathBuf) {
         {
             let mut wr = BasicCssWriter::new(&mut s, BasicCssWriterConfig { indent: "  " });
             let mut gen =
-                swc_css_codegen::CodeGenerator::new(&mut wr, CodegenConfig { minify: true });
+                swc_css_codegen::CodeGenerator::new(&mut wr, CodegenConfig { minify: false });
 
             gen.emit(&ss).unwrap();
         }
